<?php
/**
 * Plugin Name: TS Essentials: Slider Posts
 * Plugin URI: http://themestockyard.com/
 * Description: This plugin adds a new "slider posts" post type that can be used in certain ThemeStockyard themes.
 * Version: 1.2
 * Author: ThemeStockyard
 * Author URI: http://themestockyard.com/
 *
 * @since     1.0
 * @copyright Copyright (c) 2015, ThemeStockyard
 * @author    ThemeStockyard
 * @license   http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

if(function_exists('ts_essentials_posttype_supported')) {
    if(ts_essentials_posttype_supported('slider')) return; // this means it's included in the main ts_essentials plugin
}

// ThemeStockyard Essentials activated?
if ( ! defined( 'TS_ESSENTIALS_SLIDER_POSTS_PLUGIN_VERSION' ) ) {

	/* Plugin version */
	define( 'TS_ESSENTIALS_SLIDER_POSTS_PLUGIN_VERSION', '1.2' );
	
	/* Add CSS styling to backend */
    if(is_admin()) 
    {        
        add_action( 'admin_enqueue_scripts', 'ts_slider_admin_scripts' );
        function ts_slider_admin_scripts( ) {
            wp_enqueue_style( 'ts-slider', plugins_url('css/admin-style.css', __FILE__), '', TS_ESSENTIALS_SLIDER_POSTS_PLUGIN_VERSION);
        }
    }

    class TS_Slider {
    
        public static function ts_slider_wp_head() {
            ?>
            <style type="text/css">
                body.post-php.post-type-slider #edit-slug-box,
                body.post-php.post-type-slider #preview-action,
                body.post-php.post-type-slider #message.updated a { display: none !important; }
            </style>
            <?php
        }
        
        static function add_hooks() {
            add_action('init', 'TS_Slider::register_slider_post_type');	
            add_filter('manage_slider_posts_columns', 'TS_Slider::edit_columns');
            add_action('manage_slider_posts_custom_column',  'TS_Slider::custom_columns');
        }
        
        static function register_slider_post_type() {
        
            register_post_type('slider', array(             
                'labels'             => array(
                    'name'               => _x('Slider', 'Slider General Name', 'ThemeStockyard'),
                    //'menu_name'          => _x('Slider', 'Slider General Name', 'ThemeStockyard'),
                    'singular_name'      => _x('Slider Post', 'Slider Singular Name', 'ThemeStockyard'),
                    'all_items'          => __('All Slides', 'ThemeStockyard'),
                    'add_new'            => _x('Add New', 'Add New Slider Name', 'ThemeStockyard'),
                    'add_new_item'       => __('Add New Slider Post', 'ThemeStockyard'),
                    'edit_item'          => __('Edit Slider Post', 'ThemeStockyard'),
                    'new_item'           => __('New Slider Post', 'ThemeStockyard'),
                    'view_item'          => __('View Slider Post', 'ThemeStockyard'),
                    'search_items'       => __('Search Slider Posts', 'ThemeStockyard'),
                    'not_found'          => __('Nothing found', 'ThemeStockyard'),
                    'not_found_in_trash' => __('Nothing found in Trash', 'ThemeStockyard'),
                    'parent_item_colon'  => ''
                ),
                'description' => __('A post type used to be used in the main slider of recent ThemeStockyard themes.', 'ThemeStockyard'), 
                'public'             => true,
                'exclude_from_search'=> true,
                'publicly_queryable' => true,
                'show_in_nav_menus'  => false,
                'show_ui'            => true,
                'query_var'          => true,
                //'rewrite'            => array("slug" => 'slider'),
                'capability_type'    => 'post',
                //'capabilities'       => array('edit_post','delete_post'),
                'hierarchical'       => false,
                'supports'           => array('title','author','thumbnail'),
                'menu_position'     => 30,
                'has_archive'        => false,
            ));
            
            register_taxonomy(
                "slider-category", array("slider"), array(
                    "hierarchical"   => true,
                    "label"          => "Categories", 
                    "singular_label" => "Categories",
                    'show_in_nav_menus'  => false,
                    "rewrite"        => true)
            );
            
            register_taxonomy_for_object_type('slider-category', 'slider');
        }




             
        static function edit_columns($columns) {  
            $columns = array(  
                "cb"          => "<input type=\"checkbox\" />",  
                "title"       => __('Slide Title', 'ThemeStockyard'),  
                "description" => __('Slide Description' , 'ThemeStockyard'),   
                "type"        => __('Categories', 'ThemeStockyard'), 
                "photo"=> __('Photo', 'ThemeStockyard'), 
                "date"     => __('Date', 'ThemeStockyard'),
            );   
            return $columns;  
        }    
          


           
        static function custom_columns($column) {  
            global $post;  
            switch ($column) {  
                    
                 case "type":  
                    echo get_the_term_list($post->ID, 'slider-category', '', ', ','');  
                    break; 
                    
                case "description":  
                    get_the_excerpt();  
                    break;   
                    
                case "photo":  
                    the_post_thumbnail('thumbnail');
                    break; 
            }  
        } 
    }
    TS_Slider::add_hooks();


    
    //////////////////////////////////////////////////////////////////////////////
    
    
    /*-----------------------------------------------------------------------------------*/
    /* The Slider metaboxes
    /*-----------------------------------------------------------------------------------*/ 
    add_filter ('cmb_meta_boxes', 'cmb_slider_metaboxes', 502);
    function cmb_slider_metaboxes(array $meta_boxes) {
        
        global $theme_data;

        if(is_array($theme_data) && isset($theme_data['name']) && $theme_data['name'] == 'Maddux')
        {
            $prefix = '_slider_';
            
            $meta_boxes[] = array(
                'id'         => 'slider_metaboxes',
                'title'      => __('Slide Settings' , 'ThemeStockyard'),
                'pages'      => array('slider'),
                'context'    => 'normal',
                'priority'   => 'high',
                'show_names' => true,
                'fields'     => array(
                    
                           
                    array(
                        'name'    => __('Slide Content Type:' , 'ThemeStockyard'),
                        'desc'    => __('Choose current slide content type. (Add Youtube or Vimeo URL further down)' , 'ThemeStockyard'),
                        'id'      => $prefix . 'slide_type',
                        'type'    => 'select',
                        'options' => array(
                            array('name' => 'Image', 'value' => 'image'),
                            array('name' => 'Youtube', 'value' => 'youtube'),
                            array('name' => 'Vimeo', 'value' => 'vimeo')                
                            )
                    ),
                    
                    array(
                        'name' => __('Description' , 'ThemeStockyard'),
                        'desc' => __('Not used with Youtube/Vimeo videos' , 'ThemeStockyard'),
                        'id'   => $prefix . 'description',
                        'type' => 'textarea_small'
                    ),
                    
                    array(
                        'name' => __('Destination URL' , 'ThemeStockyard'),
                        'desc' => __('Not used with Youtube/Vimeo videos' , 'ThemeStockyard'),
                        'id'   => $prefix . 'url',
                        'type' => 'text'
                    ),
                    
                    array(
                        'name' => __('Launch URL in new tab?' , 'ThemeStockyard'),
                        'desc' => __('Not used with Youtube/Vimeo videos' , 'ThemeStockyard'),
                        'id'   => $prefix . 'new_tab',
                        'type' => 'checkbox'
                    ),
                    
                    array(
                        'name' => __('Hide all text?' , 'ThemeStockyard'),
                        'desc' => __('This is automatically done for videos' , 'ThemeStockyard'),
                        'id'   => $prefix . 'hide_text',
                        'type' => 'checkbox'
                    ),
                    
                    array(
                        'name' => 'Youtube & Vimeo Slide',
                        'desc' => '',
                        'type' => 'title',
                        'id'   => $prefix . 'video'
                    ),
                    
                    array(
                        'name' => __('Vimeo URL/ID here:' , 'ThemeStockyard'),
                        'desc' => __('Enter your Vimeo URL or ID here.' , 'ThemeStockyard'),
                        'id'   => $prefix . 'vimeo_id',
                        'type' => 'text'
                    ),
                    
                    array(
                        'name' => __('Youtube URL/ID here:' , 'ThemeStockyard'),
                        'desc' => __('Enter your Youtube URL or ID here.' , 'ThemeStockyard'),
                        'id'   => $prefix . 'youtube_id',
                        'type' => 'text'
                    ),
                ),
            );
        }
        else
        {
            $prefix = '_ts_essentials_slider_';
            
            $meta_boxes[] = array(
                'id'         => 'slider_metaboxes',
                'title'      => __('Slide Settings' , 'ThemeStockyard'),
                'pages'      => array('slider'),
                'context'    => 'normal',
                'priority'   => 'high',
                'show_names' => true,
                'fields'     => array(
                    
                    array(
                        'name' => __('Destination URL' , 'ThemeStockyard'),
                        'id'   => $prefix . 'url',
                        'type' => 'text'
                    ),
                    
                    array(
                        'name' => __('Launch URL in new tab?' , 'ThemeStockyard'),
                        'id'   => $prefix . 'new_tab',
                        'type' => 'checkbox'
                    ),
                    
                    array(
                        'name' => __('Hide title?' , 'ThemeStockyard'),
                        'id'   => $prefix . 'hide_text',
                        'type' => 'checkbox'
                    ),
                ),
            );
        }

        return $meta_boxes;
    }
}